pub struct RectangularBoard {
pub width: usize,
pub height: usize,
pub board: Vec<Vec<bool>>,
/* private fields */
}Fields
width: usizeheight: usizeboard: Vec<Vec<bool>>Implementations
Sourceimpl RectangularBoard
impl RectangularBoard
pub fn new(width: usize, height: usize) -> Self
Sourcepub fn l_board(n: usize, scale: usize) -> Self
pub fn l_board(n: usize, scale: usize) -> Self
Generates a new L-tetromino shaped board.
This is a two step process - first we make an L shape with long side having length n, and then we replace each box with a scale^2 box.
Sourcepub fn t_board(n: usize, scale: usize) -> Self
pub fn t_board(n: usize, scale: usize) -> Self
Generates a new T-tetromino shaped board.
This is a two step process - first we make a T shape where the two tils have length n, and then we replace each box with a scale^2 box.
Sourcepub fn is_all_marked(&self) -> bool
pub fn is_all_marked(&self) -> bool
pub fn place_tile( &self, tile_collection: &TileCollection, ) -> Vec<RectangularBoard>